Read replica routing for connection pools.
Provides ReplicaPool which routes read queries to replica databases
and write queries to the primary database.
Structs
- Replica
Pool - A pool that routes reads to replicas and writes to a primary.
Enums
- Replica
Strategy - Strategy for selecting which replica to use for reads.