pub struct PooledConnection<C: Connection> { /* private fields */ }Expand description
A connection borrowed from the pool.
When dropped, the connection is automatically returned to the pool.
The connection can be used via Deref and DerefMut.
Implementations
Sourceimpl<C: Connection> PooledConnection<C>
impl<C: Connection> PooledConnection<C>