Module replica

Module replica 

Read replica routing for connection pools.

Provides ReplicaPool which routes read queries to replica databases and write queries to the primary database.

Structs

ReplicaPool
A pool that routes reads to replicas and writes to a primary.

Enums

ReplicaStrategy
Strategy for selecting which replica to use for reads.