PooledConnection

Struct PooledConnection 

pub struct PooledConnection<C: Connection> { /* private fields */ }
A connection borrowed from the pool.

When dropped, the connection is automatically returned to the pool. The connection can be used via Deref and DerefMut.

Implementations

Source

impl<C: Connection> PooledConnection<C>

pub fn detach(self) -> C

Detach this connection from the pool.

The connection will not be returned to the pool when dropped. This is useful when you need to close a connection explicitly.

pub fn age(&self) -> Duration

Get the age of this connection (time since creation).

pub fn idle_time(&self) -> Duration

Get the idle time of this connection (time since last use).